==> zen-cart-v1.2.0-l10n-jp-5.zip: zen-cart-v1.2.0-l10n-jp-5/includes/languages/japanese/popup_search_help.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
// $Id: popup_search_help.php,v 1.4 2004/11/20 05:54:47 shidairiki Exp $
//

define('HEADING_SEARCH_HELP', 'إ');
define('TEXT_SEARCH_HELP', '(1)Τ˸򤷤ˤϡANDפORסޤϤξʣΥɤڤ뤳ȤǤޤ<br /><br /><ul><li>֥ޥե AND ޥפϤȡξΥɤޤྦʤ򸡺ޤ</li>
<li>֥ޥ OR ܡɡפϤȡɤ餫Υɤޤྦʤ򸡺ޤ</li></ul>
(2)ĤΥɤ(")ǰϤȡʸΤ˰פΤ򸡺ޤ<br /><br />
<ul><li>"Ρȷ ѥ"ϤȡʸΤ˴ޤʤ򸡺ޤ</li></ul>
(3)θ롼ϡ̤Ǥ뤳Ȥǡʣʻ꤬ǽǤ<br /><br />
<ul><li>֥ޥե AND (ܡ OR ޥ OR "visual basic")פϤȡ֥ޥեȡפޤߡġ֥ܡɡפ֥ޥפvisual basicפޤྦʤ򸡺ޤ</li></ul>');
define('TEXT_CLOSE_WINDOW', '<u>ɥĤ</u> [x]');

?>

==> zen-cart-v1.3.0.2-l10n-jp-5.zip: zen-cart-v1.3.0.2-l10n-jp-5/includes/languages/japanese/popup_search_help.php <==
<?php
//
// +----------------------------------------------------------------------+
// |zen-cart Open Source E-commerce                                       |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003 The zen-cart developers                           |
// |                                                                      |
// | http://www.zen-cart.com/index.php                                    |
// |                                                                      |
// | Portions Copyright (c) 2003 osCommerce                               |
// +----------------------------------------------------------------------+
// | This source file is subject to version 2.0 of the GPL license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.zen-cart.com/license/2_0.txt.                             |
// | If you did not receive a copy of the zen-cart license and are unable |
// | to obtain it through the world-wide-web, please send a note to       |
// | license@zen-cart.com so we can mail you a copy immediately.          |
// +----------------------------------------------------------------------+
// $Id: popup_search_help.php 2471 2005-11-29 01:14:18Z drbyte $
//

define('HEADING_SEARCH_HELP', 'إ');
define('TEXT_SEARCH_HELP', '(1)Τ˸򤷤ˤϡANDפORסޤϤξʣΥɤڤ뤳ȤǤޤ<br /><br /><ul><li>֥ޥե AND ޥפϤȡξΥɤޤྦʤ򸡺ޤ</li><li>֥ޥ OR ܡɡפϤȡɤ餫Υɤޤྦʤ򸡺ޤ</li></ul>(2)ĤΥɤ(")ǰϤȡʸΤ˰פΤ򸡺ޤ<br /><br /><ul><li>"Ρȷ ѥ"ϤȡʸΤ˴ޤʤ򸡺ޤ</li></ul>(3)θ롼ϡ̤Ǥ뤳Ȥǡʣʻ꤬ǽǤ<br /><br /><ul><li>֥ޥե AND (ܡ OR ޥ OR "visual basic")פϤȡ֥ޥեȡפޤߡġ֥ܡɡפ֥ޥפvisual basicפޤྦʤ򸡺ޤ</li></ul>');
define('TEXT_CLOSE_WINDOW', '<span class="pseudolink">ɥĤ</span> [x]');

?>
